@@ -66,7 +66,8 @@ vardchanges <- function(Y, H, PSU, w_final, id,
   if (!all(sapply(Y, is.numeric))) stop("'Y' must be numeric")
   if (any(is.na(Y))) stop("'Y' has missing values")
   if (is.null(names(Y))) stop("'Y' must have column names")
-  
+  if (any(grepl("__", names(Y)))) stop("'Y' is not allowed column names with '__'")
+
   # H
   H <- data.table(H)
   if (nrow(H) != n) stop("'H' length must be equal with 'Y' row count")
@@ -121,6 +122,7 @@ vardchanges <- function(Y, H, PSU, w_final, id,
     if (is.null(names(Dom))) stop("'Dom' must have column names")
     Dom[, (names(Dom)):=lapply(.SD, as.character)]
     if (any(is.na(Dom))) stop("'Dom' has missing values")
+    if (any(grepl("__", names(Dom)))) stop("'Dom' is not allowed column names with '__'")
   }
   
   namesZ <- NULL
@@ -130,6 +132,7 @@ vardchanges <- function(Y, H, PSU, w_final, id,
     if (ncol(Z) != m) stop("'Z' and 'Y' must be equal column count")
     if (any(is.na(Z))) stop("'Z' has missing values")
     if (is.null(names(Z))) stop("'Z' must have column names")
+    if (any(grepl("__", names(Z)))) stop("'Z' is not allowed column names with '__'")
     namesZ <- names(Z)
   }
  
