@@ -89,7 +89,8 @@ vardom <- function(Y, H, PSU, w_final,
   if (any(is.na(Y))) stop("'Y' has missing values")
   if (!all(sapply(Y, is.numeric))) stop("'Y' must be numeric values")
   if (is.null(names(Y))) stop("'Y' must have column names")
-  
+  if (any(grepl("__", names(Y)))) stop("'Y' is not allowed column names with '__'")
+
   # H
   H <- data.table(H)
   if (nrow(H) != n) stop("'H' length must be equal with 'Y' row count")
@@ -190,6 +191,7 @@ vardom <- function(Y, H, PSU, w_final,
     if (is.null(namesDom)) stop("'Dom' must have column names")
     Dom[, (namesDom):=lapply(.SD, as.character)]
     if (any(is.na(Dom))) stop("'Dom' has missing values")
+    if (any(grepl("__", names(Dom)))) stop("'Dom' is not allowed column names with '__'")
   }
   
   # Z
@@ -200,6 +202,7 @@ vardom <- function(Y, H, PSU, w_final,
     if (!all(sapply(Z, is.numeric))) stop("'Z' must be numeric values")
     if (any(is.na(Z))) stop("'Z' has missing values")
     if (is.null(names(Z))) stop("'Z' must have column names")
+    if (any(grepl("__", names(Z)))) stop("'Z' is not allowed column names with '__'")
   }
       
   # X
